//@line 36 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.2/he/mail/all-l10n.js"

//@line 38 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.2/he/mail/all-l10n.js"

pref("general.useragent.locale", "he");

// remove access keys until they are translated

pref("ui.key.generalAccessKey", 0);
pref("ui.key.menuAccessKey", 0);
